@@ -15,7 +15,7 @@ from .compat import (
 logger = logging.getLogger(__name__)
 
 
-VERSION = '0.4.5'
+VERSION = '0.4.52'
 __author__ = 'joke2k'
 __version__ = tuple(VERSION.split('.'))
 
@@ -642,7 +642,7 @@ class Env(object):
                 return
 
         try:
-            with open(env_file) if isinstance(env_file, basestring) else env_file as f:
+            with open(env_file, encoding='utf-8') if isinstance(env_file, basestring) else env_file as f:
                 content = f.read()
         except IOError:
             warnings.warn(
